@@ -9,7 +9,7 @@ import aiohttp
 from mcsniperpy.util import announce, request_manager
 from mcsniperpy.util import utils as util
 from mcsniperpy.util.classes.config import BackConfig, Config, populate_configs
-from mcsniperpy.util.name_system import api_timing, namemc_timing
+from mcsniperpy.util.name_system import api_timing, namemc_timing, teun_timing
 
 
 class Sniper:
@@ -155,9 +155,12 @@ class Sniper:
                 "init_path"), "accounts.txt")
         )
 
-        droptime = await {"kqzz_api": api_timing, "namemc": namemc_timing}.get(
-            self.timing_system, "kqzz_api"
-        )(target, self.session)
+        droptime = await {
+            "kqzz_api": api_timing,
+            "namemc": namemc_timing,
+            "teun": teun_timing
+        }.get(self.timing_system, "kqzz_api")(target, self.session)
+
 
         await self.snipe(droptime, target, offset)
 
